  Este programa serve para exibir a cotação da principais criptomoedas em tempo real.
você também pode cadastar alertas para ser informado quando uma criptomoeda atingir
determinado valor. Também é possivel fazer a conversão para real(R$).


# Dependências: 

  python3.6 + - https://www.python.org/downloads/
  
  PyQt5 - https://pypi.org/project/PyQt5 - $ pip3 install PyQt5 --user (Linux) OU pip.exe install PyQt5 (Windows)
  
  Instalando dependências em sistemas Debian/Ubuntu
  sudo apt install -y python3 python-pyqt5

# Execução apartir do código fonte.

$ git clone https://github.com/Brunopvh/coin-qt-gui.git

Entre no diretório do projeto e execute o arquivo run.py

$ cd coin-qt-gui && chmod +x run.py

$ ./run.py

# Instalando apartir do código fonte:

$ python3 setup.py install --user

No diretório raiz do projeto existe um arquivo ".desktop" para Linux.
Você pode executar a interface apartir do comando

$ python3 -m coin_qt_gui



